@@ -1,8 +1,11 @@
 package DataFlow::Meta;
 
-BEGIN {
-    $DataFlow::Meta::VERSION = '0.91.03';
-}
+#ABSTRACT: A piece of information metadata
+
+use strict;
+use warnings;
+
+our $VERSION = '0.91.04';    # VERSION
 
 use Moose;
 use DateTime;
@@ -18,17 +21,15 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
-__END__
-
 =pod
 
 =head1 NAME
 
-DataFlow::Meta - Meta-data required for DataFlow::Item
+DataFlow::Meta - A piece of information metadata
 
 =head1 VERSION
 
-version 0.91.03
+version 0.91.04
 
 =head1 SYNOPSIS
 
@@ -78,12 +79,10 @@ Please report any bugs or feature requests to
 C<bug-dataflow@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
 =head1 AUTHOR
 
 Alexei Znamensky  C<< <russoz@cpan.org> >>
 
-
 =head1 LICENCE AND COPYRIGHT
 
 Copyright (c) 2010, Alexei Znamensky C<< <russoz@cpan.org> >>. All rights reserved.
@@ -91,7 +90,6 @@ Copyright (c) 2010, Alexei Znamensky C<< <russoz@cpan.org> >>. All rights reserv
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
-
 =head1 DISCLAIMER OF WARRANTY
 
 BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
@@ -115,4 +113,17 @@ FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
 SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGES.
 
+=head1 AUTHOR
+
+Alexei Znamensky <russoz@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Alexei Znamensky.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+__END__
