@@ -1,8 +1,11 @@
 package DataFlow::Node;
 
-BEGIN {
-    $DataFlow::Node::VERSION = '0.91.03';
-}
+#ABSTRACT: A generic processing node in a data flow
+
+use strict;
+use warnings;
+
+our $VERSION = '0.91.04';    # VERSION
 
 use Moose;
 
@@ -78,6 +81,7 @@ sub process_input {
     $self->_add_output( $self->_handle_list($item) );
 
     #use Data::Dumper; warn 'process_input :: self :: after = ' . Dumper($self);
+    return;
 }
 
 ##############################################################################
@@ -128,9 +132,9 @@ sub has_queued_data {
 }
 
 sub process {
-    my $self = shift;
-    return unless @_;
-    foreach (@_) {
+    my ( $self, @args ) = @_;
+    return unless @args;
+    foreach (@args) {
         $self->input($_);
         $self->process_input;
     }
@@ -166,25 +170,20 @@ sub get_error {
 # code to handle different types of input
 #   ex: array-refs, hash-refs, code-refs, etc...
 
-use constant {
-    SVALUE => 'SVALUE',
-    OBJECT => 'OBJECT',
-};
-
 sub _param_type {
     my $p = shift;
     my $r = reftype($p);
-    return SVALUE unless $r;
-    return OBJECT if blessed($p);
+    return 'SVALUE' unless $r;
+    return 'OBJECT' if blessed($p);
     return $r;
 }
 
 sub _handle_list {
-    my $self   = shift;
+    my ( $self, @args ) = @_;
     my @result = ();
 
     #use Data::Dumper; warn '_handle_list(params) = '.Dumper(@_);
-    foreach my $item (@_) {
+    foreach my $item (@args) {
         my $type = _param_type($item);
         $self->confess('There is no handler for this parameter type!')
           unless exists $self->_handlers->{$type};
@@ -206,30 +205,30 @@ sub _handle_list {
 
 has '_handlers' => (
     is      => 'ro',
-    isa     => 'HashRef',
+    isa     => 'HashRef[CodeRef]',
     lazy    => 1,
     default => sub {
         my $me           = shift;
         my $type_handler = {
-            SVALUE => \&_handle_svalue,
-            OBJECT => \&_handle_svalue,
-            SCALAR => $me->process_into
-            ? \&_handle_scalar_ref
+            'SVALUE' => \&_handle_svalue,
+            'OBJECT' => \&_handle_svalue,
+            'SCALAR' => $me->process_into ? \&_handle_scalar_ref
             : \&_handle_svalue,
-            ARRAY => $me->process_into ? \&_handle_array_ref : \&_handle_svalue,
-            HASH  => $me->process_into ? \&_handle_hash_ref  : \&_handle_svalue,
-            CODE  => $me->process_into ? \&_handle_code_ref  : \&_handle_svalue,
+            'ARRAY' => $me->process_into ? \&_handle_array_ref
+            : \&_handle_svalue,
+            'HASH' => $me->process_into ? \&_handle_hash_ref : \&_handle_svalue,
+            'CODE' => $me->process_into ? \&_handle_code_ref : \&_handle_svalue,
+        };
+        return $type_handler unless $me->deref;
+
+        return {
+            'SVALUE' => sub { $type_handler->{'SVALUE'}->(@_) },
+            'OBJECT' => sub { $type_handler->{'OBJECT'}->(@_) },
+            'SCALAR' => sub { ${ $type_handler->{'SCALAR'}->(@_) } },
+            'ARRAY'  => sub { @{ $type_handler->{'ARRAY'}->(@_) } },
+            'HASH'   => sub { %{ $type_handler->{'HASH'}->(@_) } },
+            'CODE'   => sub { $type_handler->{'CODE'}->(@_)->() },
         };
-        return $me->deref
-          ? {
-            SVALUE => $type_handler->{SVALUE},
-            OBJECT => $type_handler->{OBJECT},
-            SCALAR => sub { ${ $type_handler->{SCALAR}->(@_) } },
-            ARRAY  => sub { @{ $type_handler->{ARRAY}->(@_) } },
-            HASH   => sub { %{ $type_handler->{HASH}->(@_) } },
-            CODE   => sub { $type_handler->{CODE}->(@_)->() },
-          }
-          : $type_handler;
     },
 );
 
@@ -268,8 +267,6 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
-__END__
-
 =pod
 
 =head1 NAME
@@ -278,7 +275,7 @@ DataFlow::Node - A generic processing node in a data flow
 
 =head1 VERSION
 
-version 0.91.03
+version 0.91.04
 
 =head1 SYNOPSIS
 
@@ -571,12 +568,10 @@ Please report any bugs or feature requests to
 C<bug-dataflow@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
 =head1 AUTHOR
 
 Alexei Znamensky  C<< <russoz@cpan.org> >>
 
-
 =head1 LICENCE AND COPYRIGHT
 
 Copyright (c) 2010-2011, Alexei Znamensky C<< <russoz@cpan.org> >>. All rights reserved.
@@ -584,7 +579,6 @@ Copyright (c) 2010-2011, Alexei Znamensky C<< <russoz@cpan.org> >>. All rights r
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
-
 =head1 DISCLAIMER OF WARRANTY
 
 BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
@@ -608,4 +602,17 @@ FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
 SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGES.
 
+=head1 AUTHOR
+
+Alexei Znamensky <russoz@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Alexei Znamensky.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+__END__
