@@ -1,9 +1,11 @@
-
 package DataFlow::Node::Encoding;
 
-BEGIN {
-    $DataFlow::Node::Encoding::VERSION = '0.91.03';
-}
+#ABSTRACT: A encoding conversion node
+
+use strict;
+use warnings;
+
+our $VERSION = '0.91.04';    # VERSION
 
 use Moose;
 extends 'DataFlow::Node';
@@ -41,3 +43,28 @@ has '+process_item' => (
 __PACKAGE__->meta->make_immutable;
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+DataFlow::Node::Encoding - A encoding conversion node
+
+=head1 VERSION
+
+version 0.91.04
+
+=head1 AUTHOR
+
+Alexei Znamensky <russoz@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Alexei Znamensky.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
