@@ -1,9 +1,11 @@
-
 package DataFlow::Node::FileData;
 
-BEGIN {
-    $DataFlow::Node::FileData::VERSION = '0.91.03';
-}
+#ABSTRACT: A node that reads that from a file
+
+use strict;
+use warnings;
+
+our $VERSION = '0.91.04';    # VERSION
 
 use Moose;
 use MooseX::Types::IO 'IO';
@@ -81,6 +83,7 @@ sub _check_eof {
         $self->_handle->close;
         $self->clear_handle;
     }
+    return;
 }
 
 override 'process_input' => sub {
@@ -111,3 +114,28 @@ override 'process_input' => sub {
 __PACKAGE__->meta->make_immutable;
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+DataFlow::Node::FileData - A node that reads that from a file
+
+=head1 VERSION
+
+version 0.91.04
+
+=head1 AUTHOR
+
+Alexei Znamensky <russoz@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Alexei Znamensky.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
