@@ -1,8 +1,11 @@
 package DataFlow::Node::NOP;
 
-BEGIN {
-    $DataFlow::Node::NOP::VERSION = '0.91.03';
-}
+#ABSTRACT: A No-Op node, input data is passed unmodified to the output
+
+use strict;
+use warnings;
+
+our $VERSION = '0.91.04';    # VERSION
 
 use Moose;
 extends 'DataFlow::Node';
@@ -17,8 +20,6 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
-__END__
-
 =pod
 
 =head1 NAME
@@ -27,7 +28,7 @@ DataFlow::Node::NOP - A No-Op node, input data is passed unmodified to the outpu
 
 =head1 VERSION
 
-version 0.91.03
+version 0.91.04
 
 =head1 SYNOPSIS
 
@@ -45,6 +46,10 @@ modifications to the output.
 
 This class is more useful as parent class than by itself.
 
+=head1 NAME
+
+DataFlow::Node::NOP - A No-Op node, input data is passed unmodified to the output
+
 =head1 METHODS
 
 The interface for C<DataFlow::Node::NOP> is the same of
@@ -98,4 +103,17 @@ FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
 SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGES.
 
+=head1 AUTHOR
+
+Alexei Znamensky <russoz@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Alexei Znamensky.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+__END__
